<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

require_once '../../../config.php';
require_once $CFG->libdir.'/gradelib.php';
require_once $CFG->dirroot.'/grade/lib.php';
require_once $CFG->dirroot.'/grade/report/multigrader/lib.php';

require_js(array('yui_yahoo', 'yui_dom', 'yui_event', 'yui_container', 'yui_connection', 'yui_dragdrop', 'yui_element'));

$courseid      = required_param('id', PARAM_INT);        // course id
$page          = optional_param('page', 0, PARAM_INT);   // active page
$perpageurl    = optional_param('perpage', 0, PARAM_INT);
$edit          = optional_param('edit', -1, PARAM_BOOL); // sticky editting mode
$sortitemid    = optional_param('sortitemid', 0, PARAM_ALPHANUM); // sort by which grade item
$action        = optional_param('action', 0, PARAM_ALPHAEXT);
$move          = optional_param('move', 0, PARAM_INT);
$type          = optional_param('type', 0, PARAM_ALPHA);
$target        = optional_param('target', 0, PARAM_ALPHANUM);
$toggle        = optional_param('toggle', NULL, PARAM_INT);
$toggle_type   = optional_param('toggle_type', 0, PARAM_ALPHANUM);

/// basic access checks
if (!$course = get_record('course', 'id', $courseid)) {
    print_error('nocourseid');
}
require_login($course);
$context = get_context_instance(CONTEXT_COURSE, $course->id);

require_capability('gradereport/multigrader:view', $context);
require_capability('moodle/grade:viewall', $context);

/// return tracking object
$gpr = new grade_plugin_return(array('type'=>'report', 'plugin'=>'multigrader', 'courseid'=>$courseid, 'page'=>$page));

//first make sure we have proper final grades - this must be done before constructing of the grade tree
grade_regrade_final_grades($courseid);

$reportname = get_string('modulename', 'gradereport_multigrader');
// Initialise the multi grader report object
/// Print header
$buttons = '';
print_grade_page_head($COURSE->id, 'report', 'multigrader', $reportname, false, null, $buttons);

if (isset($USER->access)) {
    $accessinfo = $USER->access;
} else {
    $accessinfo = get_user_access_sitewide($USER->id);
}

$courses = get_user_courses_bycap($USER->id, 'moodle/course:view', $accessinfo, true, 'c.shortname ASC');

foreach ($courses as $thiscourse) {

    $courseid = $thiscourse->id;

    // Handle toggle change request
    if (!is_null($toggle) && !empty($toggle_type)) {
        set_user_preferences(array('grade_report_show'.$toggle_type => $toggle));
    }

    // Perform actions
    if (!empty($target) && !empty($action) && confirm_sesskey()) {
        grade_report_multigrader::process_action($target, $action);
    }

    echo '<br/><br/><hr/><b><a href="'.$CFG->wwwroot.'/grade/report/grader/index.php?id='.$thiscourse->id.'">'.$thiscourse->shortname.'</a></b>';
    echo '<br/><a href="'.$CFG->wwwroot.'/grade/export/xls/index.php?id='.$thiscourse->id.'"><img src="'.$CFG->pixpath.'/f/excel.gif" alt="'.get_string('xls:view', 'gradeexport_xls').'"/></a>';
    echo '<a href="'.$CFG->wwwroot.'/grade/export/ods/index.php?id='.$thiscourse->id.'"><img src="'.$CFG->pixpath.'/f/ods.gif" alt="'.get_string('ods:view', 'gradeexport_ods').'"/></a>';
    echo '<a href="'.$CFG->wwwroot.'/grade/export/xml/index.php?id='.$thiscourse->id.'"><img src="'.$CFG->pixpath.'/f/xml.gif" alt="'.get_string('xml:view', 'gradeexport_xml').'"/></a>';
    echo '<a href="'.$CFG->wwwroot.'/grade/export/txt/index.php?id='.$thiscourse->id.'"><img src="'.$CFG->pixpath.'/f/text.gif" alt="'.get_string('txt:view', 'gradeexport_txt').'"/></a>';
    $gpr = new grade_plugin_return(array('type'=>'report', 'plugin'=>'multigrader', 'courseid'=>$courseid, 'page'=>$page));
    /// basic access checks
    if (!$course = get_record('course', 'id', $thiscourse->id)) {
        print_error('nocourseid');
    }
    $context = get_context_instance(CONTEXT_COURSE, $thiscourse->id);
    $report = new grade_report_multigrader($courseid, $gpr, $context, $page, $sortitemid);
    $numusers = $report->get_numusers();
    $studentsperpage = $report->get_pref('studentsperpage');
    // Don't use paging if studentsperpage is empty or 0 at course AND site levels
    if (!empty($studentsperpage)) {
        print_paging_bar($numusers, $report->page, $studentsperpage, $report->pbarurl);
    }

    // final grades MUST be loaded after the processing
    $report->load_users();
    $numusers = $report->get_numusers();
    $report->load_final_grades();
    echo $report->group_selector;
    echo '<div class="clearer"></div>';
    $reporthtml = '<div class="gradeparent">';
    $reporthtml .= $report->get_studentnameshtml();
    $reporthtml .= $report->get_headerhtml();
    $reporthtml .= $report->get_iconshtml();
    $reporthtml .= $report->get_studentshtml();
    $reporthtml .= $report->get_rangehtml();
    $reporthtml .= $report->get_avghtml(true);
    $reporthtml .= $report->get_avghtml();
    $reporthtml .= $report->get_endhtml();
    $reporthtml .= '</div>';

    echo $reporthtml;

    // prints paging bar at bottom for large pages
    if (!empty($studentsperpage) && $studentsperpage >= 20) {
        print_paging_bar($numusers, $report->page, $studentsperpage, $report->pbarurl);
    }
}

print_footer($course);

?>